==> latte-dock-0.9.4.tar.xz: latte-dock-0.9.4/containment/metadata.desktop.cmake <==
[Desktop Entry]
Encoding=UTF-8
Name=Latte
Name[ast]=Latte
Name[ca]=Latte
Name[ca@valencia]=Latte
Name[cs]=Latte
Name[da]=Latte
Name[de]=Latte
Name[el]=Latte
Name[en_GB]=Latte
Name[es]=Latte
Name[eu]=Latte
Name[fi]=Latte
Name[gl]=Latte
Name[id]=Latte
Name[it]=Latte
Name[ko]=Latte
Name[nl]=Latte
Name[nn]=Latte
Name[pl]=Latte
Name[pt]=Latte
Name[pt_BR]=Latte
Name[ru]=Latte
Name[sk]=Latte
Name[sv]=Latte
Name[uk]=Латте
Name[x-test]=xxLattexx
Name[zh_CN]=Latte
Name[zh_TW]=Latte
Comment=Containment provided for the Latte Dock
Comment[ca]=Intèrpret d'ordres proporcionat pel Latte Dock
Comment[ca@valencia]=Intèrpret d'ordres proporcionat pel Latte Dock
Comment[da]=Beholder til Latte-dokken
Comment[de]=Containment für Latte-Dock
Comment[el]=Περιέκτης της εφαρμογής Latte
Comment[en_GB]=Containment provided for the Latte Dock
Comment[es]=Contención proporcionada para Latte Dock
Comment[eu]=Konfinamendua hornitu da Latte Dockentzako
Comment[fi]=Latte-telakalla tarjottu sisällytys
Comment[gl]=Contedor fornecido para a doca Latte.
Comment[id]=Kontainmen disediakan untuk Dock Latte
Comment[it]=Contenitore fornito per Latte Dock
Comment[ko]=Latte 독을 위해 제공된 컨테이너
Comment[nl]=Container geleverd voor de Latte Dock
Comment[nn]=Behaldar for Latte-dokk
Comment[pl]=Pojemnik dla doku Latte
Comment[pt]=Contentor oferecido para a área acoplável do Latte
Comment[pt_BR]=Contêiner fornecido pelo Latte Dock
Comment[ru]=Контейнер Latte Dock
Comment[sk]=Politika poskytovaná pre dok Latte
Comment[sv]=Omgivning tillhandahållen för Latte dockningsfönster
Comment[uk]=Контейнер панелі Латте
Comment[x-test]=xxContainment provided for the Latte Dockxx
Comment[zh_CN]=用于 Latte 停靠栏的容器
Comment[zh_TW]=提供 Latte Dock 使用的容器

Type=Service
NoDisplay=true

X-KDE-PluginInfo-Author=@AUTHOR@
X-KDE-PluginInfo-Email=@EMAIL@
X-KDE-PluginInfo-Name=org.kde.latte.containment
X-KDE-PluginInfo-Version=@VERSION@
X-KDE-PluginInfo-Website=@WEBSITE@
X-KDE-PluginInfo-Category=X-KDE-PluginInfo-Depends=
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-EnabledByDefault=true
X-KDE-ServiceTypes=Plasma/Applet,Plasma/Containment
X-Plasma-API=declarativeappletscript
X-Plasma-MainScript=ui/main.qml
X-Plasma-ContainmentType=Panel

==> latte-dock-0.9.7.tar.xz: latte-dock-0.9.7/containment/metadata.desktop.cmake <==
[Desktop Entry]
Encoding=UTF-8
Name=Latte
Name[ast]=Latte
Name[ca]=Latte
Name[ca@valencia]=Latte
Name[cs]=Latte
Name[da]=Latte
Name[de]=Latte
Name[el]=Latte
Name[en_GB]=Latte
Name[es]=Latte
Name[eu]=Latte
Name[fi]=Latte
Name[gl]=Latte
Name[id]=Latte
Name[it]=Latte
Name[ko]=Latte
Name[nl]=Latte
Name[nn]=Latte
Name[pl]=Latte
Name[pt]=Latte
Name[pt_BR]=Latte
Name[ru]=Latte
Name[sk]=Latte
Name[sv]=Latte
Name[uk]=Латте
Name[x-test]=xxLattexx
Name[zh_CN]=Latte
Name[zh_TW]=Latte
Comment=Containment provided for the Latte Dock
Comment[ca]=Intèrpret d'ordres proporcionat pel Latte Dock
Comment[ca@valencia]=Intèrpret d'ordres proporcionat pel Latte Dock
Comment[da]=Beholder til Latte-dokken
Comment[de]=Containment für Latte-Dock
Comment[el]=Περιέκτης της εφαρμογής Latte
Comment[en_GB]=Containment provided for the Latte Dock
Comment[es]=Contención proporcionada para Latte Dock
Comment[eu]=Konfinamendua hornitu da Latte Dockentzako
Comment[fi]=Latte-telakalla tarjottu sisällytys
Comment[gl]=Contedor fornecido para a doca Latte.
Comment[id]=Kontainmen disediakan untuk Dock Latte
Comment[it]=Contenitore fornito per Latte Dock
Comment[ko]=Latte 도구집을 위해 제공된 컨테이너
Comment[nl]=Container geleverd voor de Latte Dock
Comment[nn]=Behaldar for Latte-dokk
Comment[pl]=Pojemnik dla doku Latte
Comment[pt]=Contentor oferecido para a área acoplável do Latte
Comment[pt_BR]=Contêiner fornecido pelo Latte Dock
Comment[ru]=Контейнер Latte Dock
Comment[sk]=Politika poskytovaná pre dok Latte
Comment[sv]=Omgivning tillhandahållen för Latte dockningsfönster
Comment[uk]=Контейнер панелі Латте
Comment[x-test]=xxContainment provided for the Latte Dockxx
Comment[zh_CN]=用于 Latte 停靠栏的容器
Comment[zh_TW]=提供 Latte Dock 使用的容器

Type=Service
NoDisplay=true

X-KDE-PluginInfo-Author=@AUTHOR@
X-KDE-PluginInfo-Email=@EMAIL@
X-KDE-PluginInfo-Name=org.kde.latte.containment
X-KDE-PluginInfo-Version=@VERSION@
X-KDE-PluginInfo-Website=@WEBSITE@
X-KDE-PluginInfo-Category=X-KDE-PluginInfo-Depends=
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-EnabledByDefault=true
X-KDE-ServiceTypes=Plasma/Applet,Plasma/Containment
X-Plasma-API=declarativeappletscript
X-Plasma-MainScript=ui/main.qml
X-Plasma-ContainmentType=Panel
